@@ -10,6 +10,28 @@ from order_matching.random import get_faker
 
 
 class MatchingEngine:
+    """Order Book Matching Engine.
+
+    Parameters
+    ----------
+    seed
+        Random seed
+
+    Examples
+    --------
+    >>> from order_matching.matching_engine import MatchingEngine
+    >>> from order_matching.order import LimitOrder
+    >>> from order_matching.side import Side
+    >>> matching_engine = MatchingEngine(seed=123)
+    >>> timestamp = pd.Timestamp("2023-01-01")
+    >>> transaction_timestamp = timestamp + pd.Timedelta(1, unit="D")
+    >>> buy_order = LimitOrder(side=Side.BUY, price=1.2, size=2.3, timestamp=timestamp, order_id="a", trader_id="x")
+    >>> sell_order = LimitOrder(side=Side.SELL, price=0.8, size=1.6, timestamp=timestamp, order_id="b", trader_id="y")
+    >>> executed_trades = matching_engine.match(orders=Orders([buy_order, sell_order]), timestamp=transaction_timestamp)
+    >>> print(executed_trades.trades)
+    [Trade(side=SELL, price=1.2, size=1.6, incoming_order_id='b', book_order_id='a', execution=LIMIT, trade_id='c4da537c-1651-4dae-8486-7db30d67b366', timestamp=Timestamp('2023-01-02 00:00:00'))]
+    """
+
     def __init__(self, seed: int = None) -> None:
         self._seed = seed
         self._faker = get_faker(seed=seed)
@@ -18,6 +40,20 @@ class MatchingEngine:
         self._timestamp: pd.Timestamp | None = None
 
     def match(self, timestamp: pd.Timestamp, orders: Orders = Orders()) -> ExecutedTrades:
+        """Match incoming orders in price-time priority.
+
+        Parameters
+        ----------
+        timestamp
+            Timestamp of order matching
+        orders
+            Incoming orders. Will be matched with existing ones on the order book in
+
+        Returns
+        -------
+        ExecutedTrades
+            Executed trades storage object
+        """
         self._timestamp = timestamp
         self._queue += orders
         self._queue += self._get_expired_orders()
