@@ -7,12 +7,16 @@ from order_matching.status import Status
 
 
 class BaseOrderSchema(SchemaModel):
+    """Base order schema."""
+
     side: Series[str] = Field(isin=[Side.BUY.name, Side.SELL.name])
     price: Series[float] = Field(gt=0)
     size: Series[float] = Field(gt=0)
 
 
 class OrderBookSummarySchema(BaseOrderSchema):
+    """Order book summary schema."""
+
     price: Series[float] = Field(unique=True, gt=0)
     count: Series[int] = Field(ge=0)
 
@@ -21,6 +25,8 @@ class OrderBookSummarySchema(BaseOrderSchema):
 
 
 class OrderDataSchema(BaseOrderSchema):
+    """Order data schema."""
+
     timestamp: Series[DateTime]
     expiration: Series[DateTime] = Field(nullable=True)
     order_id: Series[str]
@@ -34,6 +40,8 @@ class OrderDataSchema(BaseOrderSchema):
 
 
 class TradeDataSchema(BaseOrderSchema):
+    """Trade data schema."""
+
     timestamp: Series[DateTime]
     incoming_order_id: Series[str]
     book_order_id: Series[str]
